@@ -22,6 +22,19 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "euid.h"
+
+#include "snoopy.h"
+
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/types.h>
+
+
+
 /*
  * SNOOPY DATA SOURCE: euid
  *
@@ -30,18 +43,12 @@
  *
  * Params:
  *     result: pointer to string, to write result into
+ *     arg:    (ignored)
  *
  * Return:
- *     number of characters in the returned string
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-#include "snoopy.h"
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
-
-
-
-int snoopy_datasource_euid (char *result, char *arg)
+int snoopy_datasource_euid (char * const result, char const * const arg)
 {
     return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%u", geteuid());
 }
