@@ -25,4 +25,4 @@
 /*
  * SNOOPY DATA SOURCE: login
  */
-int snoopy_datasource_login (char *result, char *arg);
+int snoopy_datasource_login (char * const result, char const * const arg);
