@@ -72,7 +72,7 @@ int snoopy_filter_only_uid (char *msg, char const * const arg)
         uid_t  argCurUid; // Actual UID to be used for comparison
 
         // Convert literal UID to numeric type
-        argCurUid = atol(argParsed[i]);
+        argCurUid = (pid_t) atol(argParsed[i]);
 
         // Compare and return PASS if matches
         if (argCurUid == curUid) {
