@@ -31,5 +31,5 @@ void snoopy_message_generateFromFormat (
 
 void snoopy_message_append (
     char *logMessage,
-    char *appendThis
+    const char *appendThis
 );
