@@ -13,10 +13,17 @@ set -u
 ### Get data
 #
 VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE tty`
+if [ "(unknown)" == "$VAL_SNOOPY" ]; then
+    VAL_SNOOPY="(none)"
+fi
+
 if ! tty -s; then
     VAL_REAL="(none)"
 else
     VAL_REAL=`tty`
+    if [ "not a tty" == "$VAL_REAL" ]; then
+        VAL_REAL="(none)"
+    fi
 fi
 
 
